@@ -88,7 +88,7 @@ class Client(object):
 
 
     def get_customers(self, page_number: int = 1, limit_per_page: int = None, search_query: str = None,
-         is_approved: bool = None, order_by: str = None, start_date: str = None, end_date: str = None, creator_uuid: str = None) -> dict:
+         is_approved: bool = None, order_by: str = None, start_date: str = None, end_date: str = None, creator_uuid: str = None, tag = None) -> dict:
         """
         Returns a paginated list of your customers based on optional query parameters. If the customer search query parameter is used,
         the list is sorted by relevance, otherwise the customers are returned sorted by creation date, with the most recently created
@@ -104,6 +104,7 @@ class Client(object):
         :param start_data and end_date: The date filter allows you to filter customer by date intervals. The value can take any date format supported by the {TODO}.
                              The filter includes everything from the start date up to but not including the end date.
         :param creator_uuid: Returns only customers owned by this user UUID. This user must be in your organization and you must have access to their customers.
+        :param tag: Filter customers where at least one document has been marked with the descriptive tag supplied.
 
         """
         url = f"/customers?page={page_number}"
@@ -121,9 +122,20 @@ class Client(object):
             url = url + f"&endDate={end_date}"
         if creator_uuid is not None:
             url = url + f"&creator={creator_uuid}"
+        if tag is not None:
+            url = url + f"&tag={tag}"
         return self._get(url)
 
-    def upload_document(self, customer_id: str, document: object, verify_name: str = None, verify_address: str = None):
+    def upload_document(self, customer_id: str, document: object, verify_name: str = None, verify_address: str = None, tags: list = list()):
+        """
+        Uploads document(s) to a customer. Once the document(s) are uploaded, they will be queued for processing by Inscribe’s fraud detection, parsing, 
+        and optionally verification algorithms. The file size limit is 50 MB and the page limit for PDFs is 350.
+
+        :param document: The document to be uploaded
+        :param verify_name: A name that you want to verify is in a document.
+        :param verify_address: An address you want to verify is in a document
+        :param tags: A list of descriptive strings chosen by you to group documents together across customers e.g ['onboarding','new_system']
+        """
         url = f"/customers/{customer_id}/documents"
         filename = os.path.basename(document.name)
         verify_entities = []
@@ -134,8 +146,12 @@ class Client(object):
             if verify_address:
                 verify_entity["address"] = verify_address
             verify_entities.append(verify_entity)
+        formatted_tags = []
+        for tag in tags:
+            formatted_tags.append({"text": tag})
         files = {
             'verify_entities': (None, json.dumps(verify_entities), 'application/json'),
+            'tags': (None, json.dumps(formatted_tags), 'application/json'),
             'file': (filename, document, 'application/octet-stream')
         }
         return self._post(url, files=files)
